From: Andrew Cagney <cagney@gnu.org>
To: Daniel Jacobowitz <drow@false.org>
Cc: gdb-patches@sources.redhat.com
Subject: Re: [commit] multi-arch builtin-types #2 of N, language.h
Date: Wed, 28 Jul 2004 04:34:00 -0000 [thread overview]
Message-ID: <41072CD0.8070603@gnu.org> (raw)
In-Reply-To: <20040728040045.GA12728@nevyn.them.org>
[-- Attachment #1: Type: text/plain, Size: 110 bytes --]
> One correction: primative_type_vector: It's spelled "primitive".
Fixed with the attached, thanks.
Andrew
[-- Attachment #2: diffs --]
[-- Type: text/plain, Size: 3385 bytes --]
2004-07-28 Andrew Cagney <cagney@gnu.org>
* language.h (struct language_arch_info): Fix typo
s/primative/primitive/.
* gdbtypes.c (lookup_primitive_typename): Ditto.
* language.c (language_lookup_primitive_type_by_name)
(unknown_language_arch_info): Ditto.
Index: gdbtypes.c
===================================================================
RCS file: /cvs/src/src/gdb/gdbtypes.c,v
retrieving revision 1.85
diff -p -u -r1.85 gdbtypes.c
--- gdbtypes.c 28 Jul 2004 02:46:22 -0000 1.85
+++ gdbtypes.c 28 Jul 2004 04:32:45 -0000
@@ -1036,7 +1036,7 @@ type_name_no_tag (const struct type *typ
struct type *
lookup_primitive_typename (char *name)
{
- return language_lookup_primative_type_by_name (current_language,
+ return language_lookup_primitive_type_by_name (current_language,
current_gdbarch,
name);
}
Index: language.c
===================================================================
RCS file: /cvs/src/src/gdb/language.c,v
retrieving revision 1.47
diff -p -u -r1.47 language.c
--- language.c 28 Jul 2004 02:46:23 -0000 1.47
+++ language.c 28 Jul 2004 04:32:46 -0000
@@ -1283,7 +1283,7 @@ unknown_language_arch_info (struct gdbar
struct language_arch_info *lai)
{
lai->string_char_type = builtin_type (gdbarch)->builtin_char;
- lai->primative_type_vector = GDBARCH_OBSTACK_CALLOC (gdbarch, 1,
+ lai->primitive_type_vector = GDBARCH_OBSTACK_CALLOC (gdbarch, 1,
struct type *);
}
@@ -1443,16 +1443,16 @@ language_string_char_type (const struct
}
struct type *
-language_lookup_primative_type_by_name (const struct language_defn *la,
+language_lookup_primitive_type_by_name (const struct language_defn *la,
struct gdbarch *gdbarch,
const char *name)
{
struct language_gdbarch *ld = gdbarch_data (gdbarch,
language_gdbarch_data);
- if (ld->arch_info[la->la_language].primative_type_vector != NULL)
+ if (ld->arch_info[la->la_language].primitive_type_vector != NULL)
{
struct type *const *p;
- for (p = ld->arch_info[la->la_language].primative_type_vector;
+ for (p = ld->arch_info[la->la_language].primitive_type_vector;
(*p) != NULL;
p++)
{
Index: language.h
===================================================================
RCS file: /cvs/src/src/gdb/language.h,v
retrieving revision 1.28
diff -p -u -r1.28 language.h
--- language.h 28 Jul 2004 02:46:23 -0000 1.28
+++ language.h 28 Jul 2004 04:32:46 -0000
@@ -141,11 +141,11 @@ struct language_format_info
struct language_arch_info
{
/* Its primative types. This is a vector ended by a NULL pointer.
These types can be specified by name in parsing types in
expressions, regardless of whether the program being debugged
actually defines such a type. */
- struct type **primative_type_vector;
+ struct type **primitive_type_vector;
/* Type of elements of strings. */
struct type *string_char_type;
};
@@ -153,7 +153,7 @@ struct language_arch_info
struct type *language_string_char_type (const struct language_defn *l,
struct gdbarch *gdbarch);
-struct type *language_lookup_primative_type_by_name (const struct language_defn *l,
+struct type *language_lookup_primitive_type_by_name (const struct language_defn *l,
struct gdbarch *gdbarch,
const char *name);
prev parent reply other threads:[~2004-07-28 4:34 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2004-07-28 2:55 Andrew Cagney
2004-07-28 4:02 ` Daniel Jacobowitz
2004-07-28 4:18 ` Andrew Cagney
2004-07-28 14:07 ` Daniel Jacobowitz
2004-07-28 4:34 ` Andrew Cagney [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=41072CD0.8070603@gnu.org \
--to=cagney@gnu.org \
--cc=drow@false.org \
--cc=gdb-patches@sources.redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -141,11 +141,11 @@ struct language_format_info
struct language_arch_info
{
- /* Its primative types. This is a vector ended by a NULL pointer.
+ /* Its primitive types. This is a vector ended by a NULL pointer.
These types can be specified by name in parsing types in
expressions, regardless of whether the program being debugged
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox